@@ -28,24 +28,24 @@ be a "in (str, unicode)" rather than making useless version checks.
 import sys
 from abc import ABCMeta
 
-# pylint: disable=I0021,invalid-name,redefined-builtin
+# pylint: disable=I0021,invalid-name,redefined-builtin,self-assigning-variable
 
 if str is bytes:
-    import __builtin__ as builtins  # @UnresolvedImport @UnusedImport pylint: disable=I0021,import-error
+    import __builtin__ as builtins  # pylint: disable=I0021,import-error
 else:
-    import builtins  # @UnresolvedImport @Reimport pylint: disable=I0021,import-error
+    import builtins  # pylint: disable=I0021,import-error
 
 # Work around for CPython 3.x renaming "long" to "int".
 if str is bytes:
-    long = long  # @ReservedAssignment pylint: disable=I0021,undefined-variable
+    long = long  # pylint: disable=I0021,undefined-variable
 else:
-    long = int  # @ReservedAssignment
+    long = int
 
 # Work around for CPython 3.x renaming "unicode" to "str".
 if str is bytes:
-    unicode = unicode  # @ReservedAssignment pylint: disable=I0021,undefined-variable
+    unicode = unicode  # pylint: disable=I0021,undefined-variable
 else:
-    unicode = str  # @ReservedAssignment
+    unicode = str
 
 
 def iterItems(d):
@@ -56,32 +56,29 @@ def iterItems(d):
 
 
 if str is not bytes:
-    raw_input = input  # @ReservedAssignment
+    raw_input = input
+    xrange = range
+    basestring = str
 else:
-    raw_input = raw_input  # @ReservedAssignment
-
-if str is bytes:
-    xrange = xrange  # @ReservedAssignment pylint: disable=I0021,undefined-variable
-else:
-    xrange = range  # @ReservedAssignment
+    raw_input = raw_input
+    xrange = xrange  # pylint: disable=I0021,undefined-variable
+    basestring = basestring  # pylint: disable=I0021,undefined-variable
 
 
 if str is bytes:
     from urllib import (  # pylint: disable=I0021,import-error,no-name-in-module
-        urlretrieve,  # @UnresolvedImport @UnusedImport
+        urlretrieve,
     )
 else:
     from urllib.request import (  # pylint: disable=I0021,import-error,no-name-in-module
-        urlretrieve,  #  @Reimport @UnresolvedImport
+        urlretrieve,
     )
+
 if str is bytes:
-    from cStringIO import (  # pylint: disable=I0021,import-error
-        StringIO,  # @UnresolvedImport @UnusedImport
-    )
+    from cStringIO import StringIO  # pylint: disable=I0021,import-error
 else:
-    from io import (
-        StringIO,  # @UnresolvedImport @Reimport pylint: disable=I0021,import-error
-    )
+    from io import StringIO  # pylint: disable=I0021,import-error
+
 try:
     from functools import total_ordering
 except ImportError:
@@ -98,19 +95,19 @@ except ImportError:
 
 if str is bytes:
     from collections import (  # pylint: disable=I0021,import-error,no-name-in-module
-        Iterable,  # @UnresolvedImport @UnusedImport
-        MutableSet,  # @UnresolvedImport @UnusedImport
+        Iterable,
+        MutableSet,
     )
 else:
     from collections.abc import (  # pylint: disable=I0021,import-error,no-name-in-module
-        Iterable,  # @UnresolvedImport @Reimport pylint: disable=I0021,import-error
-        MutableSet,  # @UnresolvedImport @Reimport pylint: disable=I0021,import-error
+        Iterable,  # pylint: disable=I0021,import-error
+        MutableSet,  # pylint: disable=I0021,import-error
     )
 
 if str is bytes:
-    intern = intern  # @ReservedAssignment pylint: disable=I0021,undefined-variable
+    intern = intern  # pylint: disable=I0021,undefined-variable
 else:
-    intern = sys.intern  # @ReservedAssignment @UndefinedVariable
+    intern = sys.intern
 
 
 def getMetaClassBase(meta_class_prefix):
