@@ -19,12 +19,15 @@
 
 """
 
+import collections
 import hashlib
 import sys
-from abc import ABCMeta, abstractmethod
+from abc import abstractmethod
 
 from nuitka import Options
-from nuitka.__past__ import iterItems
+from nuitka.__past__ import basestring  # pylint: disable=I0021,redefined-builtin
+from nuitka.__past__ import xrange  # pylint: disable=I0021,redefined-builtin
+from nuitka.__past__ import getMetaClassBase, iterItems
 from nuitka.Builtins import (
     builtin_anon_codes,
     builtin_anon_values,
@@ -36,16 +39,6 @@ from nuitka.utils.InstanceCounters import counted_del, counted_init
 from .Namify import namifyConstant
 from .VariableDeclarations import VariableDeclaration, VariableStorage
 
-
-class ContextMetaClass(ABCMeta):
-    pass
-
-
-# For Python2/3 compatible source, we create a base class that has the metaclass
-# used and doesn't require making a choice.
-ContextMetaClassBase = ContextMetaClass("ContextMetaClassBase", (object,), {})
-
-
 # Many methods won't use self, but it's the interface. pylint: disable=no-self-use
 
 
@@ -291,6 +284,27 @@ class TempMixin(object):
         del self.cleanup_names[-1]
 
 
+CodeObjectHandle = collections.namedtuple(
+    "CodeObjectHandle",
+    (
+        "co_name",
+        "co_kind",
+        "co_varnames",
+        "co_argcount",
+        "co_posonlyargcount",
+        "co_kwonlyargcount",
+        "co_has_starlist",
+        "co_has_stardict",
+        "co_filename",
+        "line_number",
+        "future_flags",
+        "co_new_locals",
+        "has_closure",
+        "is_optimized",
+    ),
+)
+
+
 class CodeObjectsMixin(object):
     def __init__(self):
         # Code objects needed made unique by a key.
@@ -300,20 +314,21 @@ class CodeObjectsMixin(object):
         return sorted(iterItems(self.code_objects))
 
     def getCodeObjectHandle(self, code_object):
-        key = (
-            code_object.getFilename(),
-            code_object.getCodeObjectName(),
-            code_object.getLineNumber(),
-            code_object.getVarNames(),
-            code_object.getArgumentCount(),
-            code_object.getKwOnlyParameterCount(),
-            code_object.getCodeObjectKind(),
-            code_object.getFlagIsOptimizedValue(),
-            code_object.getFlagNewLocalsValue(),
-            code_object.hasStarListArg(),
-            code_object.hasStarDictArg(),
-            code_object.getFlagHasClosureValue(),
-            code_object.getFutureSpec().asFlags(),
+        key = CodeObjectHandle(
+            co_filename=code_object.getFilename(),
+            co_name=code_object.getCodeObjectName(),
+            line_number=code_object.getLineNumber(),
+            co_varnames=code_object.getVarNames(),
+            co_argcount=code_object.getArgumentCount(),
+            co_posonlyargcount=code_object.getPosOnlyParameterCount(),
+            co_kwonlyargcount=code_object.getKwOnlyParameterCount(),
+            co_kind=code_object.getCodeObjectKind(),
+            is_optimized=code_object.getFlagIsOptimizedValue(),
+            co_new_locals=code_object.getFlagNewLocalsValue(),
+            co_has_starlist=code_object.hasStarListArg(),
+            co_has_stardict=code_object.hasStarDictArg(),
+            has_closure=code_object.getFlagHasClosureValue(),
+            future_flags=code_object.getFutureSpec().asFlags(),
         )
 
         if key not in self.code_objects:
@@ -324,21 +339,19 @@ class CodeObjectsMixin(object):
     if python_version < 300:
 
         def _calcHash(self, key):
-            hash_value = hashlib.md5("%s-%s-%d-%s-%d-%d-%s-%s-%s-%s-%s-%s-%s" % key)
+            hash_value = hashlib.md5("-".join(str(s) for s in key))
 
             return hash_value.hexdigest()
 
     else:
 
         def _calcHash(self, key):
-            hash_value = hashlib.md5(
-                ("%s-%s-%d-%s-%d-%d-%s-%s-%s-%s-%s-%s-%s" % key).encode("utf-8")
-            )
+            hash_value = hashlib.md5("-".join(str(s) for s in key).encode("utf-8"))
 
             return hash_value.hexdigest()
 
 
-class PythonContextBase(ContextMetaClassBase):
+class PythonContextBase(getMetaClassBase("Context")):
     @counted_init
     def __init__(self):
         self.source_ref = None
@@ -522,7 +535,7 @@ class PythonContextBase(ContextMetaClassBase):
 
 
 class PythonChildContextBase(PythonContextBase):
-    # Base classes can be abstract, pylint: disable=abstract-method
+    # Base classes can be abstract, pylint: disable=I0021,abstract-method
 
     def __init__(self, parent):
         PythonContextBase.__init__(self)
@@ -565,6 +578,9 @@ class PythonChildContextBase(PythonContextBase):
     def getFrameVariableCodeNames(self):
         return self.parent.getFrameVariableCodeNames()
 
+    def addFunctionCreationInfo(self, creation_info):
+        return self.parent.addFunctionCreationInfo(creation_info)
+
 
 def _getConstantDefaultPopulation():
     # Lots of cases, pylint: disable=too-many-branches
@@ -581,9 +597,12 @@ def _getConstantDefaultPopulation():
         False,
         0,
         1,
+        -1,
         # Some math operations shortcut to these
         0.0,
         -0.0,
+        1.0,
+        -1.0,
         # For Python3 empty bytes, no effect for Python2, same as "", used for
         # code objects.
         b"",
@@ -731,7 +750,7 @@ class PythonGlobalContext(object):
             # TODO: Maybe make this a mapping in nuitka.Builtins
 
             if constant is None:
-                key = "(PyObject *)Py_TYPE( Py_None )"
+                key = "(PyObject *)Py_TYPE(Py_None)"
             elif constant is object:
                 key = "(PyObject *)&PyBaseObject_Type"
             elif constant is staticmethod:
@@ -746,15 +765,9 @@ class PythonGlobalContext(object):
                 key = "(PyObject *)&PyFrozenSet_Type"
             elif python_version >= 270 and constant is memoryview:
                 key = "(PyObject *)&PyMemoryView_Type"
-            elif (
-                python_version < 300
-                and constant is basestring  # pylint: disable=I0021,undefined-variable
-            ):
+            elif python_version < 300 and constant is basestring:
                 key = "(PyObject *)&PyBaseString_Type"
-            elif (
-                python_version < 300
-                and constant is xrange  # pylint: disable=I0021,undefined-variable
-            ):
+            elif python_version < 300 and constant is xrange:
                 key = "(PyObject *)&PyRange_Type"
             elif constant in builtin_anon_values:
                 key = "(PyObject *)" + builtin_anon_codes[builtin_anon_values[constant]]
@@ -997,6 +1010,8 @@ class PythonModuleContext(
 
         self.variable_storage = VariableStorage(heap_name=None)
 
+        self.function_table_entries = []
+
     def __repr__(self):
         return "<PythonModuleContext instance for module %s>" % self.filename
 
@@ -1068,6 +1083,16 @@ class PythonModuleContext(
     def needsModuleFilenameObject(self):
         return self.needs_module_filename_object
 
+    def addFunctionCreationInfo(self, creation_info):
+        self.function_table_entries.append(creation_info)
+
+    def getFunctionCreationInfos(self):
+        result = self.function_table_entries
+
+        # Release the memory once possible.
+        del self.function_table_entries
+        return result
+
 
 class PythonFunctionContext(
     FrameDeclarationsMixin,
@@ -1124,9 +1149,6 @@ class PythonFunctionDirectContext(PythonFunctionContext):
     def isForDirectCall(self):
         return True
 
-    def isForCrossModuleUsage(self):
-        return self.function.isCrossModuleUsed()
-
     def isForCreatedFunction(self):
         return False
 
@@ -1138,9 +1160,6 @@ class PythonGeneratorObjectContext(PythonFunctionContext):
     def isForDirectCall(self):
         return False
 
-    def isForCrossModuleUsage(self):
-        return self.function.isCrossModuleUsed()
-
     def isForCreatedFunction(self):
         return False
 
