@@ -39,18 +39,17 @@ def _getStoreLocalsCode(locals_name, variable_traces, is_dict, emit, context):
 
             if is_dict:
                 emit(
-                    "%s = PyDict_GetItem( %s, %s );"
-                    % (value_name, locals_name, key_name)
+                    "%s = PyDict_GetItem(%s, %s);" % (value_name, locals_name, key_name)
                 )
             else:
                 emit(
-                    "%s = PyObject_GetItem( %s, %s );"
+                    "%s = PyObject_GetItem(%s, %s);"
                     % (value_name, locals_name, key_name)
                 )
 
                 getErrorExitBoolCode(
                     condition="""\
-%s == NULL && !EXCEPTION_MATCH_BOOL_SINGLE( GET_ERROR_OCCURRED(), PyExc_KeyError )"""
+%s == NULL && !EXCEPTION_MATCH_BOOL_SINGLE(GET_ERROR_OCCURRED(), PyExc_KeyError)"""
                     % value_name,
                     emit=emit,
                     context=context,
@@ -60,7 +59,7 @@ def _getStoreLocalsCode(locals_name, variable_traces, is_dict, emit, context):
 
                 context.addCleanupTempName(value_name)
 
-            emit("if ( %s != NULL )" % value_name)
+            emit("if (%s != NULL)" % value_name)
             emit("{")
 
             getVariableAssignmentCode(
@@ -175,7 +174,7 @@ def _getBuiltinCompileCode(
             optimize_name,
         )
 
-    emit("%s = COMPILE_CODE( %s );" % (to_name, ", ".join(str(arg) for arg in args)))
+    emit("%s = COMPILE_CODE(%s);" % (to_name, ", ".join(str(arg) for arg in args)))
 
     getErrorExitCode(
         check_name=to_name,
@@ -219,7 +218,7 @@ def getBuiltinEvalCode(
     )
 
     emit(
-        "%s = EVAL_CODE( %s, %s, %s );"
+        "%s = EVAL_CODE(%s, %s, %s);"
         % (to_name, compiled_name, globals_name, locals_name)
     )
 
@@ -283,7 +282,7 @@ def generateExecCode(statement, emit, context):
     res_name = context.getBoolResName()
 
     emit(
-        "%s = EXEC_FILE_ARG_HANDLING( &%s, &%s );"
+        "%s = EXEC_FILE_ARG_HANDLING(&%s, &%s);"
         % (res_name, source_name, filename_name)
     )
 
@@ -306,7 +305,7 @@ def generateExecCode(statement, emit, context):
     to_name = context.allocateTempName("exec_result")
 
     emit(
-        "%s = EVAL_CODE( %s, %s, %s );"
+        "%s = EVAL_CODE(%s, %s, %s);"
         % (to_name, compiled_name, globals_name, locals_name)
     )
 
