@@ -1,4 +1,4 @@
-#     Copyright 2017, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -25,9 +25,9 @@ certain conditions.
 See Developer Manual for how the CPython loops are mapped to these nodes.
 """
 
+from .CodeHelpers import generateStatementSequenceCode
 from .ErrorCodes import getErrorExitBoolCode
 from .ExceptionCodes import getExceptionUnpublishedReleaseCode
-from .Helpers import generateStatementSequenceCode
 from .LabelCodes import getGotoCode, getLabelCode
 
 
@@ -65,22 +65,22 @@ def generateLoopCode(statement, emit, context):
     old_loop_continue = context.setLoopContinueTarget(loop_start_label)
 
     generateStatementSequenceCode(
-        statement_sequence = statement.getLoopBody(),
-        allow_none         = True,
-        emit               = emit,
-        context            = context
+        statement_sequence=statement.getLoopBody(),
+        allow_none=True,
+        emit=emit,
+        context=context,
     )
 
     context.setLoopBreakTarget(old_loop_break)
     context.setLoopContinueTarget(old_loop_continue)
 
     # Note: We are using the wrong line here, but it's an exception, it's unclear what line it would be anyway.
-    old_source_ref = context.setCurrentSourceCodeReference(statement.getSourceReference())
+    old_source_ref = context.setCurrentSourceCodeReference(
+        statement.getSourceReference()
+    )
 
     getErrorExitBoolCode(
-        condition = "CONSIDER_THREADING() == false",
-        emit      = emit,
-        context   = context
+        condition="CONSIDER_THREADING() == false", emit=emit, context=context
     )
 
     context.setCurrentSourceCodeReference(old_source_ref)
