@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -22,12 +22,14 @@ types then have to overload the class methods.
 """
 
 type_indicators = {
-    "PyObject *" : 'o',
-    "PyObject **" : 'O',
-    "struct Nuitka_CellObject *" : 'c',
-    "nuitka_bool" : 'b'
+    "PyObject *": "o",
+    "PyObject **": "O",
+    "struct Nuitka_CellObject *": "c",
+    "nuitka_bool": "b",
+    "nuitka_ilong": "L",
 }
 
+
 class CTypeBase(object):
     # For overload.
     c_type = None
@@ -36,7 +38,6 @@ class CTypeBase(object):
     def getTypeIndicator(cls):
         return type_indicators[cls.c_type]
 
-
     @classmethod
     def getInitValue(cls, init_from):
         """ Convert to init value for the type. """
@@ -50,13 +51,13 @@ class CTypeBase(object):
 
         return "%s%s%s = %s;" % (
             cls.c_type,
-            ' ' if cls.c_type[-1] not in '*' else "",
+            " " if cls.c_type[-1] not in "*" else "",
             variable_code_name,
-            init_value
+            init_value,
         )
 
     @classmethod
-    def getLocalVariableInitTestCode(cls, variable_code_name):
+    def getLocalVariableInitTestCode(cls, value_name, inverted):
         """ Get code to test for uninitialized.
 
         """
@@ -64,10 +65,10 @@ class CTypeBase(object):
         # Need to overload this for each type it is used for, pylint: disable=unused-argument
         assert False, cls.c_type
 
-
     @classmethod
-    def getLocalVariableAssignCode(cls, variable_code_name, needs_release,
-                                   tmp_name, ref_count, in_place):
+    def emitVariableAssignCode(
+        cls, value_name, needs_release, tmp_name, ref_count, in_place, emit, context
+    ):
         """ Get code to assign local variable.
 
         """
@@ -76,8 +77,9 @@ class CTypeBase(object):
         assert False, cls.c_type
 
     @classmethod
-    def getDeleteObjectCode(cls, variable_code_name, needs_check, tolerant,
-                            variable, emit, context):
+    def getDeleteObjectCode(
+        cls, to_name, value_name, needs_check, tolerant, emit, context
+    ):
         """ Get code to delete (del) local variable.
 
         """
@@ -112,6 +114,13 @@ class CTypeBase(object):
         # Need to overload this for each type it is used for, pylint: disable=unused-argument
         assert False, cls.c_type
 
+    @classmethod
+    def emitAssignmentCodeFromBoolCondition(cls, to_name, condition, emit):
+        """ Get the assignment code from C boolean condition.
+
+        """
+        # Need to overload this for each type it is used for, pylint: disable=unused-argument
+        assert False, cls.c_type
 
     @classmethod
     def getReleaseCode(cls, variable_code_name, needs_check, emit):
