@@ -20,7 +20,7 @@
 """
 
 template_asyncgen_object_maker_template = """\
-static PyObject *%(function_identifier)s_maker( void );
+static PyObject *%(function_identifier)s_maker(void);
 """
 
 template_asyncgen_object_body_template = """
@@ -28,10 +28,9 @@ struct %(function_identifier)s_locals {
 %(function_local_types)s
 };
 
-static PyObject *%(function_identifier)s_context( struct Nuitka_AsyncgenObject *asyncgen, PyObject *yield_return_value )
-{
-    CHECK_OBJECT( (PyObject *)asyncgen );
-    assert( Nuitka_Asyncgen_Check( (PyObject *)asyncgen ) );
+static PyObject *%(function_identifier)s_context( struct Nuitka_AsyncgenObject *asyncgen, PyObject *yield_return_value ) {
+    CHECK_OBJECT((PyObject *)asyncgen);
+    assert(Nuitka_Asyncgen_Check((PyObject *)asyncgen));
 
     // Heap access if used.
 %(heap_declaration)s
@@ -48,8 +47,7 @@ static PyObject *%(function_identifier)s_context( struct Nuitka_AsyncgenObject *
 %(asyncgen_exit)s
 }
 
-static PyObject *%(function_identifier)s_maker( void )
-{
+static PyObject *%(function_identifier)s_maker(void) {
     return Nuitka_Asyncgen_New(
         %(function_identifier)s_context,
         %(asyncgen_module)s,
@@ -69,18 +67,18 @@ template_make_asyncgen = """\
 
 template_asyncgen_exception_exit = """\
     // Return statement must be present.
-    NUITKA_CANNOT_GET_HERE( %(function_identifier)s );
+    NUITKA_CANNOT_GET_HERE(%(function_identifier)s);
 
     function_exception_exit:
 %(function_cleanup)s\
-    assert( %(exception_type)s );
-    RESTORE_ERROR_OCCURRED( %(exception_type)s, %(exception_value)s, %(exception_tb)s );
+    assert(%(exception_type)s);
+    RESTORE_ERROR_OCCURRED(%(exception_type)s, %(exception_value)s, %(exception_tb)s);
     return NULL;
 """
 
 template_asyncgen_noexception_exit = """\
     // Return statement must be present.
-    NUITKA_CANNOT_GET_HERE( %(function_identifier)s );
+    NUITKA_CANNOT_GET_HERE(%(function_identifier)s);
 
 %(function_cleanup)s\
 
