@@ -20,29 +20,22 @@
 """
 
 template_publish_exception_to_handler = """\
-if ( %(keeper_tb)s == NULL )
-{
+if (%(keeper_tb)s == NULL) {
     %(keeper_tb)s = %(tb_making)s;
-}
-else if ( %(keeper_lineno)s != 0 )
-{
-    %(keeper_tb)s = ADD_TRACEBACK( %(keeper_tb)s, %(frame_identifier)s, %(keeper_lineno)s );
+} else if (%(keeper_lineno)s != 0) {
+    %(keeper_tb)s = ADD_TRACEBACK(%(keeper_tb)s, %(frame_identifier)s, %(keeper_lineno)s);
 }
 """
 
 template_error_catch_quick_exception = """\
-if ( %(condition)s )
-{
-    if ( !ERROR_OCCURRED() )
-    {
+if (%(condition)s) {
+    if (!ERROR_OCCURRED()) {
         %(exception_type)s = %(quick_exception)s;
-        Py_INCREF( %(exception_type)s );
+        Py_INCREF(%(exception_type)s);
         %(exception_value)s = NULL;
         %(exception_tb)s = NULL;
-    }
-    else
-    {
-        FETCH_ERROR_OCCURRED( &%(exception_type)s, &%(exception_value)s, &%(exception_tb)s );
+    } else {
+        FETCH_ERROR_OCCURRED(&%(exception_type)s, &%(exception_value)s, &%(exception_tb)s);
     }
 %(release_temps)s
 
@@ -52,11 +45,10 @@ if ( %(condition)s )
 }"""
 
 template_error_catch_exception = """\
-if ( %(condition)s )
-{
-    assert( ERROR_OCCURRED() );
+if (%(condition)s) {
+    assert(ERROR_OCCURRED());
 
-    FETCH_ERROR_OCCURRED( &%(exception_type)s, &%(exception_value)s, &%(exception_tb)s );
+    FETCH_ERROR_OCCURRED(&%(exception_type)s, &%(exception_value)s, &%(exception_tb)s);
 %(release_temps)s
 
 %(line_number_code)s
@@ -65,8 +57,7 @@ if ( %(condition)s )
 }"""
 
 template_error_format_string_exception = """\
-if ( %(condition)s )
-{
+if (%(condition)s) {
 %(release_temps)s
 %(set_exception)s
 
