@@ -34,20 +34,20 @@ from .AssignNodes import (
 )
 from .ConditionalNodes import ExpressionConditional
 from .ConstantRefNodes import ExpressionConstantDictEmptyRef
-from .ExpressionBases import ExpressionBase, ExpressionChildrenHavingBase
+from .ExpressionBases import ExpressionBase, ExpressionChildHavingBase
 from .NodeBases import StatementBase, StatementChildHavingBase
 from .VariableRefNodes import ExpressionTempVariableRef
 
 
-class ExpressionLocalsVariableRefORFallback(ExpressionChildrenHavingBase):
+class ExpressionLocalsVariableRefOrFallback(ExpressionChildHavingBase):
     kind = "EXPRESSION_LOCALS_VARIABLE_REF_OR_FALLBACK"
 
-    named_children = ("fallback",)
+    named_child = "fallback"
+
+    __slots__ = ("locals_scope", "variable", "variable_trace")
 
     def __init__(self, locals_scope, variable_name, fallback, source_ref):
-        ExpressionChildrenHavingBase.__init__(
-            self, values={"fallback": fallback}, source_ref=source_ref
-        )
+        ExpressionChildHavingBase.__init__(self, value=fallback, source_ref=source_ref)
 
         assert locals_scope is not None
 
@@ -176,7 +176,7 @@ class ExpressionLocalsVariableRefORFallback(ExpressionChildrenHavingBase):
             return (
                 result,
                 "new_expression",
-                "Moved call of uncertain dict variable to inside.",
+                "Moved call of uncertain dict variable '%s' to inside." % variable_name,
             )
 
         return call_node, None, None
@@ -187,8 +187,9 @@ class ExpressionLocalsVariableRefORFallback(ExpressionChildrenHavingBase):
         )
 
 
-class ExpressionLocalsMappingVariableRefORFallback(
-    ExpressionLocalsVariableRefORFallback
+# TODO: Why is this unused.
+class ExpressionLocalsMappingVariableRefOrFallback(
+    ExpressionLocalsVariableRefOrFallback
 ):
     kind = "EXPRESSION_LOCALS_MAPPING_VARIABLE_REF_OR_FALLBACK"
 
@@ -322,6 +323,8 @@ class StatementLocalsDictOperationSet(StatementChildHavingBase):
     kind = "STATEMENT_LOCALS_DICT_OPERATION_SET"
 
     named_child = "value"
+    # TODO: Child name inconsistent with accessor name.
+    getAssignSource = StatementChildHavingBase.childGetter("value")
 
     __slots__ = ("variable", "variable_version", "variable_trace", "locals_scope")
 
@@ -360,9 +363,6 @@ class StatementLocalsDictOperationSet(StatementChildHavingBase):
     def getLocalsDictScope(self):
         return self.locals_scope
 
-    # TODO: Child name inconsistent with accessor name.
-    getAssignSource = StatementChildHavingBase.childGetter("value")
-
     def computeStatement(self, trace_collection):
         if self.locals_scope.isMarkedForPropagation():
             variable_name = self.getVariableName()
@@ -416,12 +416,18 @@ class StatementLocalsDictOperationSet(StatementChildHavingBase):
 class StatementLocalsDictOperationDel(StatementBase):
     kind = "STATEMENT_LOCALS_DICT_OPERATION_DEL"
 
-    __slots__ = "variable", "variable_version", "previous_trace", "locals_scope"
+    __slots__ = (
+        "variable",
+        "variable_version",
+        "previous_trace",
+        "locals_scope",
+        "tolerant",
+    )
 
     # TODO: Specialize for Python3 maybe to save attribute for Python2.
     may_raise_del = python_version >= 300
 
-    def __init__(self, locals_scope, variable_name, source_ref):
+    def __init__(self, locals_scope, variable_name, tolerant, source_ref):
         assert type(variable_name) is str
 
         StatementBase.__init__(self, source_ref=source_ref)
@@ -433,6 +439,8 @@ class StatementLocalsDictOperationDel(StatementBase):
         self.variable = locals_scope.getLocalsDictVariable(variable_name)
         self.variable_version = self.variable.allocateTargetNumber()
 
+        self.tolerant = tolerant
+
         self.previous_trace = None
 
     def finalize(self):
@@ -500,7 +508,7 @@ class StatementLocalsDictOperationDel(StatementBase):
         return self, None, None
 
     def mayRaiseException(self, exception_type):
-        return self.may_raise_del
+        return self.may_raise_del and not self.tolerant
 
     def getStatementNiceName(self):
         return "locals dictionary value del statement"
@@ -510,6 +518,8 @@ class StatementSetLocals(StatementChildHavingBase):
     kind = "STATEMENT_SET_LOCALS"
 
     named_child = "new_locals"
+    getNewLocals = StatementChildHavingBase.childGetter("new_locals")
+    getAssignSource = getNewLocals
 
     __slots__ = ("locals_scope",)
 
@@ -535,9 +545,6 @@ class StatementSetLocals(StatementChildHavingBase):
     def mayRaiseException(self, exception_type):
         return self.getNewLocals().mayRaiseException(exception_type)
 
-    getNewLocals = StatementChildHavingBase.childGetter("new_locals")
-    getAssignSource = getNewLocals
-
     def computeStatement(self, trace_collection):
         trace_collection.onExpression(self.getNewLocals())
         new_locals = self.getNewLocals()
