@@ -27,6 +27,10 @@ from abc import ABCMeta
 from nuitka.__past__ import intern  # pylint: disable=I0021,redefined-builtin
 
 
+class NuitkaNodeDesignError(Exception):
+    pass
+
+
 def _checkBases(name, bases):
     # Avoid duplicate base classes.
     assert len(bases) == len(set(bases)), (name, bases)
@@ -38,7 +42,9 @@ def _checkBases(name, bases):
         is_mixin = base_name.endswith("Mixin")
 
         if is_mixin and last_mixin is False:
-            assert False, (name, bases)
+            raise NuitkaNodeDesignError(
+                "Mixins must come first in base classes.", bases
+            )
 
         last_mixin = is_mixin
 
@@ -46,8 +52,8 @@ def _checkBases(name, bases):
 class NodeCheckMetaClass(ABCMeta):
     kinds = {}
 
-    # This is in conflict with either PyDev or Pylint 1.9.2 used fo Python2, it
-    # should be "mcs" for one and "cls" for the other.
+    # This is in conflict with Pylint 1.9.2 used for Python2, it
+    # should be "mcls" for one and "cls" for the other.
     # pylint: disable=I0021,bad-mcs-classmethod-argument
 
     def __new__(cls, name, bases, dictionary):  # pylint: disable=I0021,arguments-differ
@@ -59,6 +65,12 @@ class NodeCheckMetaClass(ABCMeta):
         if "named_child" in dictionary:
             dictionary["__slots__"] += (intern("subnode_" + dictionary["named_child"]),)
 
+        if "named_children" in dictionary and not name.endswith("Base"):
+            if len(dictionary["named_children"]) <= 1:
+                raise NuitkaNodeDesignError(
+                    "Use ExpressionChildHaving for one child node classes", name
+                )
+
         # Not a method:
         if "checker" in dictionary:
             dictionary["checker"] = staticmethod(dictionary["checker"])
@@ -78,13 +90,7 @@ class NodeCheckMetaClass(ABCMeta):
             NodeCheckMetaClass.kinds[kind] = cls
             NodeCheckMetaClass.kinds[name] = cls
 
-            def convert(value):
-                if value in ("AND", "OR", "NOT"):
-                    return value
-                else:
-                    return value.title()
-
-            kind_to_name_part = "".join([convert(x) for x in kind.split("_")])
+            kind_to_name_part = "".join([x.title() for x in kind.split("_")])
             assert name.endswith(kind_to_name_part), (name, kind_to_name_part)
 
             # Automatically add checker methods for everything to the common
