@@ -32,6 +32,7 @@ from nuitka.nodes.AttributeNodes import (
     ExpressionBuiltinHasattr,
     ExpressionBuiltinSetattr,
 )
+from nuitka.nodes.BuiltinAllNodes import ExpressionBuiltinAll
 from nuitka.nodes.BuiltinAnyNodes import ExpressionBuiltinAny
 from nuitka.nodes.BuiltinComplexNodes import (
     ExpressionBuiltinComplex1,
@@ -110,8 +111,9 @@ from nuitka.nodes.NodeMakingHelpers import (
     wrapExpressionWithSideEffects,
 )
 from nuitka.nodes.OperatorNodes import (
+    ExpressionOperationAbs,
     ExpressionOperationBinaryDivmod,
-    ExpressionOperationNOT,
+    ExpressionOperationNot,
     ExpressionOperationUnary,
 )
 from nuitka.nodes.OutlineNodes import ExpressionOutlineBody
@@ -463,6 +465,31 @@ def len_extractor(node):
     )
 
 
+def all_extractor(node):
+    # pylint: disable=unused-argument
+    def makeAll0(source_ref):
+        exception_message = "all() takes exactly one argument (0 given)"
+
+        return makeRaiseExceptionReplacementExpressionFromInstance(
+            expression=node, exception=TypeError(exception_message)
+        )
+
+    return BuiltinParameterSpecs.extractBuiltinArgs(
+        node=node,
+        builtin_class=ExpressionBuiltinAll,
+        builtin_spec=BuiltinParameterSpecs.builtin_all_spec,
+        empty_special_class=makeAll0,
+    )
+
+
+def abs_extractor(node):
+    return BuiltinParameterSpecs.extractBuiltinArgs(
+        node=node,
+        builtin_class=ExpressionOperationAbs,
+        builtin_spec=BuiltinParameterSpecs.builtin_abs_spec,
+    )
+
+
 def any_extractor(node):
     # pylint: disable=unused-argument
     def makeAny0(source_ref):
@@ -856,7 +883,7 @@ def eval_extractor(node):
                 variable=source_variable, source=source, source_ref=source_ref
             ),
             makeStatementConditional(
-                condition=ExpressionOperationNOT(
+                condition=ExpressionOperationNot(
                     operand=ExpressionBuiltinIsinstance(
                         instance=ExpressionTempVariableRef(
                             variable=source_variable, source_ref=source_ref
@@ -1279,6 +1306,8 @@ _dispatch_dict = {
     "repr": repr_extractor,
     "len": len_extractor,
     "any": any_extractor,
+    "abs": abs_extractor,
+    "all": all_extractor,
     "super": super_extractor,
     "hasattr": hasattr_extractor,
     "getattr": getattr_extractor,
