@@ -1,4 +1,4 @@
-#     Copyright 2017, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -27,18 +27,15 @@ def goHome():
     """ Go its own directory, to have it easy with path knowledge.
 
     """
-    os.chdir(
-        getHomePath()
-    )
+    os.chdir(getHomePath())
+
+
+my_abs_path = os.path.abspath(__file__)
+
 
 def getHomePath():
-    return os.path.normpath(
-        os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
-            "..",
-            ".."
-        )
-    )
+    return os.path.normpath(os.path.join(os.path.dirname(my_abs_path), "..", ".."))
+
 
 def setupPATH():
     """ Make sure installed tools are in PATH.
@@ -46,13 +43,13 @@ def setupPATH():
     For Windows, add this to the PATH, so pip installed PyLint will be found
     near the Python executing this script.
     """
-    os.environ["PATH"] = os.environ["PATH"] + \
-                         os.pathsep + \
-                         os.path.join(os.path.dirname(sys.executable),"scripts")
+    os.environ["PATH"] = (
+        os.environ["PATH"]
+        + os.pathsep
+        + os.path.join(os.path.dirname(sys.executable), "scripts")
+    )
+
 
 def addPYTHONPATH(path):
     python_path = os.environ.get("PYTHONPATH", "")
-    os.environ["PYTHONPATH"] = os.pathsep.join(
-        python_path.split(os.pathsep) + \
-        [path]
-    )
+    os.environ["PYTHONPATH"] = os.pathsep.join(python_path.split(os.pathsep) + [path])
