@@ -53,8 +53,9 @@ import os
 import sys
 from logging import info, warning
 
-from nuitka import Options, SourceCodeReferences
+from nuitka import Options, OutputDirectories, SourceCodeReferences
 from nuitka.__past__ import long, unicode  # pylint: disable=I0021,redefined-builtin
+from nuitka.freezer.Standalone import detectEarlyImports
 from nuitka.importing import Importing
 from nuitka.importing.ImportCache import addImportedModule
 from nuitka.importing.PreloadedPackages import getPthImportedPackages
@@ -109,6 +110,7 @@ from nuitka.plugins.Plugins import Plugins
 from nuitka.PythonVersions import python_version
 from nuitka.utils import MemoryUsage
 from nuitka.utils.FileOperations import splitPath
+from nuitka.utils.ModuleNames import ModuleName
 
 from . import SyntaxErrors
 from .ReformulationAssertStatements import buildAssertNode
@@ -117,6 +119,7 @@ from .ReformulationAssignmentStatements import (
     buildAssignNode,
     buildDeleteNode,
     buildInplaceAssignNode,
+    buildNamedExprNode,
 )
 from .ReformulationBooleanExpressions import buildBoolOpNode
 from .ReformulationCallExpressions import buildCallNode
@@ -179,8 +182,11 @@ def buildVariableReferenceNode(provider, node, source_ref):
 
 
 # Python3.4 or higher, True and False, are not given as variables anymore.
+# Python3.8, all kinds of constants are like this.
 def buildNamedConstantNode(node, source_ref):
-    return makeConstantRefNode(constant=node.value, source_ref=source_ref)
+    return makeConstantRefNode(
+        constant=node.value, source_ref=source_ref, user_provided=True
+    )
 
 
 def buildConditionNode(provider, node, source_ref):
@@ -388,7 +394,9 @@ def handleNonlocalDeclarationNode(provider, node, source_ref):
             )
 
     provider.addNonlocalsDeclaration(
-        names=node.names, source_ref=source_ref.atColumnNumber(node.col_offset)
+        names=tuple(node.names),
+        user_provided=True,
+        source_ref=source_ref.atColumnNumber(node.col_offset),
     )
 
     # Drop this, not really part of our tree.
@@ -651,6 +659,7 @@ setBuildingDispatchers(
         "Break": buildStatementLoopBreak,
         "JoinedStr": buildJoinedStrNode,
         "FormattedValue": buildFormattedValueNode,
+        "NamedExpr": buildNamedExprNode,
     },
     path_args2={
         "Constant": buildNamedConstantNode,  # Python3.8
@@ -835,10 +844,26 @@ def buildParseTree(provider, source_code, source_ref, is_module, is_main):
         assert False
 
 
-def decideModuleTree(filename, package, is_shlib, is_top, is_main):
-    # Many variables, branches, due to the many cases, pylint: disable=too-many-branches,too-many-statements
+def decideCompilationMode(is_top, module_name, source_ref):
+    result = Plugins.decideCompilation(module_name, source_ref)
 
-    assert package is None or type(package) is str
+    if result == "bytecode" and is_top:
+        warning(
+            """\
+Ignoring plugin decision to compile top level package '%s'
+as bytecode, the extension module entry point is technically
+required to compiled."""
+            % module_name
+        )
+        result = "compiled"
+
+    return result
+
+
+def decideModuleTree(filename, package, is_shlib, is_top, is_main):
+    # Many variables, branches, due to the many cases, pylint: disable=too-many-branches
+
+    assert package is None or type(package) is ModuleName
     assert filename is not None
 
     if is_main and os.path.isdir(filename):
@@ -863,15 +888,14 @@ def decideModuleTree(filename, package, is_shlib, is_top, is_main):
         source_ref = SourceCodeReferences.fromFilename(filename=filename)
 
         if is_main:
-            module_name = "__main__"
+            module_name = ModuleName("__main__")
         else:
+            # Derive module name from filename.
             module_name = os.path.basename(filename)
-
-            if module_name.endswith(".py"):
-                module_name = module_name[:-3]
-
             if is_shlib:
                 module_name = module_name.split(".")[0]
+            elif module_name.endswith(".py"):
+                module_name = module_name[:-3]
 
             if "." in module_name:
                 sys.stderr.write(
@@ -880,28 +904,22 @@ def decideModuleTree(filename, package, is_shlib, is_top, is_main):
 
                 sys.exit(2)
 
+            module_name = ModuleName.makeModuleNameInPackage(module_name, package)
+
         if is_shlib:
-            result = PythonShlibModule(
-                name=module_name, package_name=package, source_ref=source_ref
-            )
+            result = PythonShlibModule(module_name=module_name, source_ref=source_ref)
         elif is_main:
             result = PythonMainModule(
                 main_added=main_added,
-                mode=Plugins.decideCompilation("__main__", source_ref),
+                mode=decideCompilationMode(False, module_name, source_ref),
                 future_spec=None,
                 source_ref=source_ref,
             )
         else:
-            if package is not None:
-                full_name = package + "." + module_name
-            else:
-                full_name = module_name
-
             result = CompiledPythonModule(
-                name=module_name,
-                package_name=package,
+                module_name=module_name,
                 is_top=is_top,
-                mode=Plugins.decideCompilation(full_name, source_ref),
+                mode=decideCompilationMode(is_top, module_name, source_ref),
                 future_spec=None,
                 source_ref=source_ref,
             )
@@ -912,14 +930,13 @@ def decideModuleTree(filename, package, is_shlib, is_top, is_main):
         else:
             module_name = os.path.basename(filename)
 
+        module_name = ModuleName.makeModuleNameInPackage(module_name, package)
+
         source_filename = os.path.join(filename, "__init__.py")
 
         if not os.path.isfile(source_filename):
             source_ref, result = createNamespacePackage(
-                module_name=module_name,
-                package_name=package,
-                is_top=is_top,
-                module_relpath=filename,
+                module_name=module_name, is_top=is_top, module_relpath=filename
             )
             source_filename = None
         else:
@@ -927,21 +944,13 @@ def decideModuleTree(filename, package, is_shlib, is_top, is_main):
                 filename=os.path.abspath(source_filename)
             )
 
-            if package is not None:
-                full_name = package + "." + module_name
-            else:
-                full_name = module_name
-
             result = CompiledPythonPackage(
-                name=module_name,
-                package_name=package,
+                module_name=module_name,
                 is_top=is_top,
-                mode=Plugins.decideCompilation(full_name, source_ref),
+                mode=decideCompilationMode(is_top, module_name, source_ref),
                 future_spec=None,
                 source_ref=source_ref,
             )
-
-            assert result.getFullName() == full_name, result
     else:
         sys.stderr.write(
             "%s: can't open file '%s'.\n" % (os.path.basename(sys.argv[0]), filename)
@@ -1006,6 +1015,14 @@ def buildModuleTree(filename, package, is_top, is_main):
         is_shlib=False,
     )
 
+    if is_top:
+        OutputDirectories.setMainModule(module)
+
+        # Detect to be frozen modules if any, so we can consider to not recurse
+        # to them.
+        if Options.isStandaloneMode():
+            detectEarlyImports()
+
     # If there is source code associated (not the case for namespace packages of
     # Python3.3 or higher, then read it.
     if source_filename is not None:
