@@ -28,7 +28,7 @@ from nuitka.nodes.AssignNodes import (
 )
 from nuitka.nodes.ComparisonNodes import makeComparisonExpression
 from nuitka.nodes.ConditionalNodes import makeStatementConditional
-from nuitka.nodes.OperatorNodes import ExpressionOperationNOT
+from nuitka.nodes.OperatorNodes import ExpressionOperationNot
 from nuitka.nodes.OutlineNodes import ExpressionOutlineBody
 from nuitka.nodes.ReturnNodes import StatementReturn
 from nuitka.nodes.VariableRefNodes import ExpressionTempVariableRef
@@ -110,7 +110,7 @@ def buildComplexComparisonNode(provider, left, rights, comparators, source_ref):
         )
 
         yield makeStatementConditional(
-            condition=ExpressionOperationNOT(
+            condition=ExpressionOperationNot(
                 operand=ExpressionTempVariableRef(
                     variable=tmp_variable, source_ref=source_ref
                 ),
