@@ -153,6 +153,7 @@ def buildFunctionNode(provider, node, source_ref):
                 name=node.name,
                 code_object=code_object,
                 flags=flags,
+                auto_release=None,
                 source_ref=source_ref,
             )
 
@@ -163,6 +164,7 @@ def buildFunctionNode(provider, node, source_ref):
                 name=node.name,
                 code_object=code_object,
                 flags=flags,
+                auto_release=None,
                 source_ref=source_ref,
             )
 
@@ -311,6 +313,7 @@ def buildAsyncFunctionNode(provider, node, source_ref):
             name=node.name,
             code_object=code_object,
             flags=flags,
+            auto_release=None,
             source_ref=source_ref,
         )
     else:
@@ -319,6 +322,7 @@ def buildAsyncFunctionNode(provider, node, source_ref):
             name=node.name,
             code_object=code_object,
             flags=flags,
+            auto_release=None,
             source_ref=source_ref,
         )
 
@@ -464,7 +468,7 @@ def buildParameterAnnotations(provider, node, source_ref):
         keys.append(mangle(key))
         values.append(value)
 
-    def extractArg(arg):
+    def extractArgAnnotation(arg):
         if getKind(arg) == "Name":
             assert arg.annotation is None
         elif getKind(arg) == "arg":
@@ -475,15 +479,19 @@ def buildParameterAnnotations(provider, node, source_ref):
                 )
         elif getKind(arg) == "Tuple":
             for sub_arg in arg.elts:
-                extractArg(sub_arg)
+                extractArgAnnotation(sub_arg)
         else:
             assert False, getKind(arg)
 
+    if python_version >= 380:
+        for arg in node.args.posonlyargs:
+            extractArgAnnotation(arg)
+
     for arg in node.args.args:
-        extractArg(arg)
+        extractArgAnnotation(arg)
 
     for arg in node.args.kwonlyargs:
-        extractArg(arg)
+        extractArgAnnotation(arg)
 
     if python_version < 340:
         if node.args.varargannotation is not None:
@@ -499,9 +507,9 @@ def buildParameterAnnotations(provider, node, source_ref):
             )
     else:
         if node.args.vararg is not None:
-            extractArg(node.args.vararg)
+            extractArgAnnotation(node.args.vararg)
         if node.args.kwarg is not None:
-            extractArg(node.args.kwarg)
+            extractArgAnnotation(node.args.kwarg)
 
     # Return value annotation (not there for lambdas)
     if hasattr(node, "returns") and node.returns is not None:
@@ -682,14 +690,15 @@ def buildFunctionWithParsing(
 
         return normal_args
 
-    normal_args = extractNormalArgs(node.args.args)
-
     parameters = ParameterSpec(
         ps_name=name,
-        ps_normal_args=normal_args,
+        ps_normal_args=extractNormalArgs(node.args.args),
+        ps_pos_only_args=[extractArg(arg) for arg in node.args.posonlyargs]
+        if python_version >= 380
+        else (),
         ps_kw_only_args=[extractArg(arg) for arg in node.args.kwonlyargs]
         if python_version >= 300
-        else [],
+        else (),
         ps_list_star_arg=extractArg(node.args.vararg),
         ps_dict_star_arg=extractArg(node.args.kwarg),
         ps_default_count=len(node.args.defaults),
@@ -707,6 +716,7 @@ def buildFunctionWithParsing(
         co_kind=function_kind,
         co_varnames=parameters.getParameterNames(),
         co_argcount=parameters.getArgumentCount(),
+        co_posonlyargcount=parameters.getPosOnlyParameterCount(),
         co_kwonlyargcount=parameters.getKwOnlyParameterCount(),
         co_has_starlist=parameters.getStarListArgumentName() is not None,
         co_has_stardict=parameters.getStarDictArgumentName() is not None,
@@ -722,6 +732,7 @@ def buildFunctionWithParsing(
         flags=flags,
         doc=function_doc,
         parameters=parameters,
+        auto_release=None,
         source_ref=source_ref,
     )
 
@@ -750,7 +761,7 @@ def addFunctionVariableReleases(function):
     source_ref = function.getSourceReference()
 
     for variable in function.getLocalVariables():
-        # Shared variables are freed by function object attachment.
+        # Shared variables are freed by function attachment.
         if variable.getOwner() is not function:
             continue
 
@@ -769,5 +780,3 @@ def addFunctionVariableReleases(function):
         )
 
         function.setBody(makeStatementsSequenceFromStatement(statement=body))
-
-        # assert body.isStatementAborting(), body.asXmlText()
