@@ -123,14 +123,9 @@ def detectFunctionBodyKind(nodes, start_value=None):
 
         if node_class is ast.Yield:
             indications.add("Generator")
-        elif (
-            python_version >= 300 and node_class is ast.YieldFrom
-        ):  # @UndefinedVariable
+        elif python_version >= 300 and node_class is ast.YieldFrom:
             indications.add("Generator")
-        elif python_version >= 350 and node_class in (
-            ast.Await,
-            ast.AsyncWith,
-        ):  # @UndefinedVariable
+        elif python_version >= 350 and node_class in (ast.Await, ast.AsyncWith):
             indications.add("Coroutine")
 
         # Recurse to children, but do not cross scope boundary doing so.
@@ -151,7 +146,7 @@ def detectFunctionBodyKind(nodes, start_value=None):
                     assert False, (name, field, ast.dump(node))
         elif node_class in (ast.FunctionDef, ast.Lambda) or (
             python_version >= 350 and node_class is ast.AsyncFunctionDef
-        ):  # @UndefinedVariable
+        ):
             for name, field in ast.iter_fields(node):
                 if name in ("name", "body"):
                     pass
@@ -197,7 +192,8 @@ def detectFunctionBodyKind(nodes, start_value=None):
                             if gen.is_async:
                                 indications.add("Coroutine")
                                 break
-                            elif _checkCoroutine(gen):
+
+                            if _checkCoroutine(gen):
                                 break
                 else:
                     assert False, (name, field, ast.dump(node))
@@ -211,7 +207,7 @@ def detectFunctionBodyKind(nodes, start_value=None):
                     _check(field)
                 else:
                     assert False, (name, field, ast.dump(node))
-        elif python_version >= 270 and node_class is ast.SetComp:  # @UndefinedVariable
+        elif python_version >= 270 and node_class is ast.SetComp:
             for name, field in ast.iter_fields(node):
                 if name in ("name", "body", "comparators", "elt"):
                     pass
@@ -219,7 +215,7 @@ def detectFunctionBodyKind(nodes, start_value=None):
                     _check(field[0].iter)
                 else:
                     assert False, (name, field, ast.dump(node))
-        elif python_version >= 270 and node_class is ast.DictComp:  # @UndefinedVariable
+        elif python_version >= 270 and node_class is ast.DictComp:
             for name, field in ast.iter_fields(node):
                 if name in ("name", "body", "comparators", "key", "value"):
                     pass
@@ -289,8 +285,6 @@ def buildNode(provider, node, source_ref, allow_none=False):
 
         if hasattr(node, "lineno"):
             source_ref = source_ref.atLineNumber(node.lineno)
-        else:
-            source_ref = source_ref
 
         if kind in build_nodes_args3:
             result = build_nodes_args3[kind](
@@ -366,7 +360,7 @@ def buildAnnotationNode(provider, node, source_ref):
         # there is no accessible "ast.unparse", and this works as a hack
         # to convert our node to a string annotation, pylint: disable=exec-used
         m = {}
-        exec(r, m)  # @UndefinedVariable
+        exec(r, m)
 
         return makeConstantRefNode(
             constant=m["__annotations__"]["x"], source_ref=source_ref
@@ -393,6 +387,7 @@ def makeModuleFrame(module, statements, source_ref):
             co_kind="Module",
             co_varnames=(),
             co_argcount=0,
+            co_posonlyargcount=0,
             co_kwonlyargcount=0,
             co_has_starlist=False,
             co_has_stardict=False,
